fermentationInTwoNations: An '.xlsx' and a '.pdf' file giving the answers (Excel file)...

Description Details FileNames ReadingTheData Author(s) References Examples

Description

fermentationInTwoNations: An .xlsx file and a .pdf file giving the results (Excel file) to a questionnaire (pdf file) about fermented products. These results come from a study about the social representations of fermented products in France and Vietnam. The excel file name is fermentedFoodSurvey.xlsx (the data are stored in the sheet" data4MCA), and the questionnaire is in the file questionnaireFermentation.pdf.

Details

The excel file includes data from 373 participants (220 French and 153 Vietnamese participants) to the original study plus 30 "new" participants (students from the 2018 SPISE Workshop). A detailed analysis of these data is given in the vignette fermentationIn2NationsMCA from the R4SPISE2018 package.

FileNames

fermentedFoodSurvey.xlsx and questionnaireFermentation.pdf

ReadingTheData

To fetch this dataset use system.file() (see example below).

Author(s)

Chollet, S.

References

These data were used in a project directed by Professor Sylvie Chollet.

Examples

1
2
3
4
5
6
7
8
## Not run: 
# to get the path of the files:
path2file.pdf <- system.file("extdata",
       "questionnaireFermentation.pdf", package = "R4SPISE2018")
path2file.xlsx <- system.file("extdata",
       "fermentedFoodSurvey.xlsx", package = "R4SPISE2018")
          
## End(Not run)

HerveAbdi/R4SPISE2018 documentation built on Sept. 3, 2020, 6:40 a.m.